/* $Id: ssh_global.c,v 1.4 2000/09/22 01:19:01 andrew Exp $ */

/*
 * Copyright 1999 RedBack Networks, Incorporated.
 * All rights reserved.
 *
 * This software is not in the public domain.  It is distributed 
 * under the terms of the license in the file LICENSE in the
 * same directory as this file.  If you have received a copy of this
 * software without the LICENSE file (which means that whoever gave
 * you this software violated its license) you may obtain a copy from
 * http://www.panix.com/~tls/LICENSE.txt
 */


#include "sshd.h"
#include "ssh_cipher.h"

struct ssh_cipher g_cipher;
ssh_context_t g_context;
int nodaemon;
